@@ -15,10 +15,10 @@ limitations under the License.
 
 """
 
-import falcon
-from six import iteritems
 import uuid
 
+import falcon
+
 from freezer_api.api.common import resource
 from freezer_api.common import exceptions as freezer_api_exc
 from freezer_api import policy
@@ -115,9 +115,15 @@ class JobsResource(JobsBaseResource):
     def on_delete(self, req, resp, job_id):
         # DELETE /v1/jobs/{job_id}     Deletes the specified job
         user_id = req.get_header('X-User-ID')
-        self.db.delete_job(user_id=user_id, job_id=job_id)
-        resp.body = {'job_id': job_id}
-        resp.status = falcon.HTTP_204
+        obj = self.db.get_job(user_id=user_id, job_id=job_id)
+        if not obj:
+            raise freezer_api_exc.DocumentNotFound(
+                message='No Job found with ID:{0}'.
+                format(job_id))
+        else:
+            self.db.delete_job(user_id=user_id, job_id=job_id)
+            resp.body = {'job_id': job_id}
+            resp.status = falcon.HTTP_204
 
     @policy.enforce('jobs:update')
     def on_patch(self, req, resp, job_id):
@@ -164,7 +170,7 @@ class JobsEvent(resource.BaseResource):
         doc = self.json_body(req)
 
         try:
-            event, params = next(iteritems(doc))
+            event, params = next(iter(doc.items()))
         except Exception:
             raise freezer_api_exc.BadDataFormat("Bad event request format")
 
@@ -258,6 +264,8 @@ class Job(object):
     def start(self, params=None):
         if self.job_schedule.get('event') != 'start':
             self.job_schedule['event'] = 'start'
+            self.job_schedule['status'] = ''
+            self.job_schedule['result'] = ''
             self.need_update = True
             return 'success'
         return 'start already requested'
@@ -288,10 +296,11 @@ class Job(object):
     def expand_default_properties(self):
         action_defaults = self.doc.pop("action_defaults")
         if isinstance(action_defaults, dict):
-            for key, val in iteritems(action_defaults):
+            for key, val in action_defaults.items():
                 for action in self.doc.get("job_actions"):
                     if action["freezer_action"].get(key) is None:
                         action["freezer_action"][key] = val
         else:
-            raise freezer_api_exc.BadDataFormat(message="action_defaults should"
-                                                        "be a dictionary")
+            raise freezer_api_exc.BadDataFormat(
+                message="action_defaults shouldbe a dictionary"
+            )
