@@ -24,14 +24,14 @@ from freezer_api import policy
 
 class ActionsCollectionResource(resource.BaseResource):
     """
-    Handler for endpoint: /v1/actions
+    Handler for endpoint: /v2/{project_id}/actions
     """
     def __init__(self, storage_driver):
         self.db = storage_driver
 
     @policy.enforce('actions:get_all')
     def on_get(self, req, resp, project_id):
-        # GET /v1/actions(?limit,offset)     Lists actions
+        # GET /v2/{project_id}/actions(?limit,offset)     Lists actions
         user_id = req.get_header('X-User-ID')
         offset = req.get_param_as_int('offset', min=0) or 0
         limit = req.get_param_as_int('limit', min=1) or 10
@@ -43,7 +43,7 @@ class ActionsCollectionResource(resource.BaseResource):
 
     @policy.enforce('actions:create')
     def on_post(self, req, resp, project_id):
-        # POST /v1/actions    Creates action entry
+        # POST /v2/{project_id}/actions    Creates action entry
         doc = self.json_body(req)
         if not doc:
             raise freezer_api_exc.BadDataFormat(
@@ -58,7 +58,7 @@ class ActionsCollectionResource(resource.BaseResource):
 
 class ActionsResource(resource.BaseResource):
     """
-    Handler for endpoint: /v1/actions/{action_id}
+    Handler for endpoint: /v2/{project_id}/actions/{action_id}
     """
 
     def __init__(self, storage_driver):
@@ -66,7 +66,8 @@ class ActionsResource(resource.BaseResource):
 
     @policy.enforce('actions:get')
     def on_get(self, req, resp, project_id, action_id):
-        # GET /v1/actions/{action_id}     retrieves the specified action
+        # GET /v2/{project_id}/actions/{action_id}
+        # retrieves the specified action
         # search in body
         user_id = req.get_header('X-User-ID') or ''
         obj = self.db.get_action(project_id=project_id,
@@ -79,7 +80,8 @@ class ActionsResource(resource.BaseResource):
 
     @policy.enforce('actions:delete')
     def on_delete(self, req, resp, project_id, action_id):
-        # DELETE /v1/actions/{action_id}     Deletes the specified action
+        # DELETE /v2/{project_id}/actions/{action_id}
+        # Deletes the specified action
         user_id = req.get_header('X-User-ID')
         self.db.delete_action(project_id=project_id,
                               user_id=user_id,
@@ -89,7 +91,8 @@ class ActionsResource(resource.BaseResource):
 
     @policy.enforce('actions:update')
     def on_patch(self, req, resp, project_id, action_id):
-        # PATCH /v1/actions/{action_id}     updates the specified action
+        # PATCH /v2/{project_id}/actions/{action_id}
+        # updates the specified action
         user_id = req.get_header('X-User-ID') or ''
         doc = self.json_body(req)
         new_version = self.db.update_action(project_id=project_id,
@@ -100,7 +103,8 @@ class ActionsResource(resource.BaseResource):
 
     @policy.enforce('actions:replace')
     def on_post(self, req, resp, project_id, action_id):
-        # PUT /v1/actions/{action_id}    creates/replaces the specified action
+        # PUT /v2/{project_id}/actions/{action_id}
+        # Creates/Replaces the specified action
         user_id = req.get_header('X-User-ID') or ''
         doc = self.json_body(req)
         new_version = self.db.replace_action(project_id=project_id,
